@@ -1,7 +1,7 @@
 package Config::IOD;
 
-our $DATE = '2019-01-17'; # DATE
-our $VERSION = '0.350'; # VERSION
+our $DATE = '2021-06-21'; # DATE
+our $VERSION = '0.351'; # VERSION
 
 use 5.010001;
 use strict;
@@ -194,7 +194,7 @@ Config::IOD - Read and write IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.350 of Config::IOD (from Perl distribution Config-IOD), released on 2019-01-17.
+This document describes version 0.351 of Config::IOD (from Perl distribution Config-IOD), released on 2021-06-21.
 
 =head1 SYNOPSIS
 
@@ -442,9 +442,25 @@ L<IOD::Examples> - sample documents
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Steven Haryanto u1
+
+=over 4
+
+=item *
+
+Steven Haryanto <sharyanto@cpan.org>
+
+=item *
+
+u1 <u1@backpacker.localdomain>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
