@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
-our $DATE = '2019-01-17'; # DATE
-our $VERSION = '0.350'; # VERSION
+our $DATE = '2021-06-21'; # DATE
+our $VERSION = '0.351'; # VERSION
 
 use 5.010;
 use strict;
@@ -209,13 +209,14 @@ sub each_key {
             next if $skip_section;
             my $key = $line->[COL_K_KEY];
             next if $opts->{unique_key} && $seen_keys{$key}++;
-            $code->(
+            my $res = $code->(
                 $self,
                 linum     => $linum,
                 section   => $cur_section,
                 key       => $key,
                 raw_value => $line->[COL_K_VALUE_RAW],
             );
+            return if $opts->{early_exit} && !$res;
         }
     }
 }
@@ -272,6 +273,24 @@ sub list_keys {
     @res;
 }
 
+sub key_exists {
+    my $self = shift;
+    my ($section, $key) = @_;
+
+    my $found;
+    $self->each_key(
+        {early_exit=>1},
+        sub {
+            my ($self, %args) = @_;
+            return 1 unless $args{section} eq $section;
+            return 1 unless $args{key} eq $key;
+            $found++;
+            return 0;
+        },
+    );
+    $found;
+}
+
 sub _find_section {
     my $self = shift;
     my $opts;
@@ -322,7 +341,7 @@ sub each_section {
             $linum_end++;
         }
 
-        $code->(
+        my $res = $code->(
             $self,
             linum       => $linum,
             linum_start => $linum,
@@ -330,6 +349,7 @@ sub each_section {
             parsed      => $parsed->[$linum-1],
             section     => $section,
         );
+        return if $opts->{early_exit} && !$res;
     }
 }
 
@@ -353,6 +373,23 @@ sub list_sections {
     @res;
 }
 
+sub section_exists {
+    my $self = shift;
+    my ($section) = @_;
+
+    my $found;
+    $self->each_section(
+        {early_exit=>1},
+        sub {
+            my ($self, %args) = @_;
+            return 1 unless $args{section} eq $section;
+            $found++;
+            return 0;
+        },
+    );
+    $found;
+}
+
 sub _get_section_line_range {
     my $self = shift;
     my $opts;
@@ -784,7 +821,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.350 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2019-01-17.
+This document describes version 0.351 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2021-06-21.
 
 =head1 SYNOPSIS
 
@@ -962,6 +999,11 @@ If set to 1, will only list the first occurence of each section.
 
 If set to 1, will only list the first occurence of each key in the same section.
 
+=item * early_exit => bool
+
+If set to 1, then if coderef returns false will return early immediately and not
+continue to the next key.
+
 =back
 
 =head2 $doc->each_section([ \%opts , ] $code) => LIST
@@ -980,6 +1022,11 @@ Options:
 
 If set to 1, will only list the first occurence of each section.
 
+=item * early_exit => bool
+
+If set to 1, then if coderef returns false will return early immediately and not
+continue to the next section.
+
 =back
 
 =head2 $doc->empty()
@@ -1091,6 +1138,16 @@ If set to 1, will only list the first occurrence of each key.
 
 =back
 
+=head2 $doc->key_exists([ \%opts ], $section, $key) => bool
+
+Check whether a key exists.
+
+Options:
+
+=over
+
+=back
+
 =head2 $doc->list_sections([ \%opts ]) => LIST
 
 List sections in the document, in order of occurrence.
@@ -1105,6 +1162,16 @@ If set to 1, will only list the first occurrence of each section.
 
 =back
 
+=head2 $doc->section_exists([ \%opts ], $section) => bool
+
+Check whether a section exists.
+
+Options:
+
+=over
+
+=back
+
 =head2 $doc->set_value([ \%opts ], $section, $key, $new_value)
 
 Set value of a key.
@@ -1143,7 +1210,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
